import "./tasks/fastqc.wdl" as fastqc
import "./tasks/fastqscreen.wdl" as fastqscreen
import "./tasks/mapping.wdl" as mapping
import "./tasks/Dedup.wdl" as Dedup
import "./tasks/qualimap.wdl" as qualimap
import "./tasks/deduped_Metrics.wdl" as deduped_Metrics
import "./tasks/sentieon.wdl" as sentieon
import "./tasks/Realigner.wdl" as Realigner
import "./tasks/BQSR.wdl" as BQSR
import "./tasks/Haplotyper.wdl" as Haplotyper
import "./tasks/filter_bed.wdl" as filter_bed
import "./tasks/benchmark.wdl" as benchmark


workflow  {{ project_name }}  {

	File read1
	File read2

	String SENTIEON_INSTALL_DIR
	String SENTIEON_LICENSE
	String SENTIEONdocker
	String FASTQCdocker
	String FASTQSCREENdocker
	String BENCHMARKdocker
	String BEDTOOLSdocker
	String QUALIMAPdocker

	String fasta
	File ref_dir
	File dbmills_dir
	String db_mills
	File dbsnp_dir
	String dbsnp
	File bed
	File benchmark_region
	File screen_ref_dir
	File fastq_screen_conf
	File benchmarking_dir
	String sample_name
	String disk_size
	String BIGcluster_config
	String SMALLcluster_config


		call fastqc.fastqc as fastqc {
			input:
			read1=read1,
			read2=read2,
			docker=FASTQCdocker,
			cluster_config=BIGcluster_config,
			disk_size=disk_size
		}

		call fastqscreen.fastq_screen as fastqscreen {
			input:
			read1=read1,
			read2=read2,
			screen_ref_dir=screen_ref_dir,
			fastq_screen_conf=fastq_screen_conf,

			docker=FASTQSCREENdocker,
			cluster_config=BIGcluster_config,
			disk_size=disk_size
		}

		call mapping.mapping as mapping {
			input: 
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			SENTIEON_LICENSE=SENTIEON_LICENSE,
			group=sample_name,
			sample=sample_name,
			pl="ILLUMINAL",
			fasta=fasta,
			ref_dir=ref_dir,
			fastq_1=read1,
			fastq_2=read2,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}

		call Dedup.Dedup as Dedup {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			sorted_bam=mapping.sorted_bam,
			sorted_bam_index=mapping.sorted_bam_index,
			sample=sample_name,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}

		call qualimap.qualimap as qualimap {
			input:
			bam=Dedup.Dedup_bam,
			bai=Dedup.Dedup_bam_index,
			bed=bed,
			docker=QUALIMAPdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}		

		call deduped_Metrics.deduped_Metrics as deduped_Metrics {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			fasta=fasta,
			ref_dir=ref_dir,
			bed=bed,
			Dedup_bam=Dedup.Dedup_bam,
			Dedup_bam_index=Dedup.Dedup_bam_index,
			sample=sample_name,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}

		call Realigner.Realigner as Realigner {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			fasta=fasta,
			ref_dir=ref_dir,
			Dedup_bam=Dedup.Dedup_bam,
			Dedup_bam_index=Dedup.Dedup_bam_index,
			db_mills=db_mills,
			dbmills_dir=dbmills_dir,
			sample=sample_name,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}

		call BQSR.BQSR as BQSR {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			fasta=fasta,
			ref_dir=ref_dir,
			realigned_bam=Realigner.realigner_bam,
			realigned_bam_index=Realigner.realigner_bam_index,
			db_mills=db_mills,
			dbmills_dir=dbmills_dir,
			dbsnp=dbsnp,
			dbsnp_dir=dbsnp_dir,
			sample=sample_name,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}

		call Haplotyper.Haplotyper as Haplotyper {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			fasta=fasta,
			ref_dir=ref_dir,
			recaled_bam=BQSR.recaled_bam,
			recaled_bam_index=BQSR.recaled_bam_index,
			sample=sample_name,
			docker=SENTIEONdocker,
			disk_size=disk_size,
			cluster_config=BIGcluster_config
		}


	call filter_bed.filter_bed as filter_bed {
		input:
		bed=bed,
		benchmark_region=benchmark_region,
		docker=BEDTOOLSdocker,
		cluster_config=SMALLcluster_config,
		disk_size=disk_size
	}

		call benchmark.benchmark as benchmark {
			input:
			vcf=Haplotyper.vcf,
			benchmarking_dir=benchmarking_dir,
			filtered_bed=filter_bed.filtered_bed,
			ref_dir=ref_dir,
			fasta=fasta,
			docker=BENCHMARKdocker,
			cluster_config=BIGcluster_config,
			disk_size=disk_size
		}	
}

